==> 2205.0.tar.gz: o3de/Gems/ScriptCanvasDeveloper/Code/Editor/Include/ScriptCanvasDeveloperEditor/EditorAutomation/EditorAutomationStates/GraphStates.h <==
/*
 * Copyright (c) Contributors to the Open 3D Engine Project.
 * For complete copyright and license terms please see the LICENSE at the root of this distribution.
 *
 * SPDX-License-Identifier: Apache-2.0 OR MIT
 *
 */
#pragma once

#include <GraphCanvas/Editor/AssetEditorBus.h>
#include <GraphCanvas/Types/Types.h>

#include <ScriptCanvasDeveloperEditor/EditorAutomation/EditorAutomationActions/ScriptCanvasActions/GraphActions.h>

namespace ScriptCanvasDeveloper
{
    /**
        EditorAutomationState that will create a runtime graph
    */
    DefineStateId(CreateRuntimeGraphState);

    class CreateRuntimeGraphState 
    : public StaticIdAutomationState<CreateRuntimeGraphStateId>
    {
    public:

        CreateRuntimeGraphState();
        ~CreateRuntimeGraphState() override = default;

    protected:

        void OnSetupStateActions(EditorAutomationActionRunner& actionRunner) override;
        void OnStateActionsComplete() override;

    private:

        CreateNewGraphAction m_createNewGraphAction;
    };

    /**
        EditorAutomationState that will create a function graph
    */
    DefineStateId(CreateFunctionGraphState);

    class CreateFunctionGraphState 
        : public StaticIdAutomationState<CreateFunctionGraphStateId>
    {
    public:

        CreateFunctionGraphState();
        ~CreateFunctionGraphState() override = default;

    protected:

        void OnSetupStateActions(EditorAutomationActionRunner& actionRunner) override;

        void OnStateActionsComplete() override;

    private:

        CreateNewFunctionAction m_createNewFunctionAction;
    };

    /**
        EditorAutomationState that will force close the currently opened graph, bypassing any save prompts.
    */
    DefineStateId(ForceCloseActiveGraphState);

    class ForceCloseActiveGraphState 
        : public StaticIdAutomationState<ForceCloseActiveGraphStateId>
    {
    public:

        ForceCloseActiveGraphState();
        ~ForceCloseActiveGraphState() override = default;

    protected:

        void OnSetupStateActions(EditorAutomationActionRunner& actionRunner) override;

    private:

        ForceCloseActiveGraphAction m_forceCloseActiveGraph;
    };
}

==> 2210.0.tar.gz: o3de/Gems/ScriptCanvasDeveloper/Code/Editor/Include/ScriptCanvasDeveloperEditor/EditorAutomation/EditorAutomationStates/GraphStates.h <==
/*
 * Copyright (c) Contributors to the Open 3D Engine Project.
 * For complete copyright and license terms please see the LICENSE at the root of this distribution.
 *
 * SPDX-License-Identifier: Apache-2.0 OR MIT
 *
 */
#pragma once

#include <GraphCanvas/Editor/AssetEditorBus.h>
#include <GraphCanvas/Types/Types.h>

#include <ScriptCanvasDeveloperEditor/EditorAutomation/EditorAutomationActions/ScriptCanvasActions/GraphActions.h>

namespace ScriptCanvas::Developer
{
    /**
        EditorAutomationState that will create a runtime graph
    */
    DefineStateId(CreateRuntimeGraphState);

    class CreateRuntimeGraphState 
    : public StaticIdAutomationState<CreateRuntimeGraphStateId>
    {
    public:

        CreateRuntimeGraphState();
        ~CreateRuntimeGraphState() override = default;

    protected:

        void OnSetupStateActions(EditorAutomationActionRunner& actionRunner) override;
        void OnStateActionsComplete() override;

    private:

        CreateNewGraphAction m_createNewGraphAction;
    };

    /**
        EditorAutomationState that will create a function graph
    */
    DefineStateId(CreateFunctionGraphState);

    class CreateFunctionGraphState 
        : public StaticIdAutomationState<CreateFunctionGraphStateId>
    {
    public:

        CreateFunctionGraphState();
        ~CreateFunctionGraphState() override = default;

    protected:

        void OnSetupStateActions(EditorAutomationActionRunner& actionRunner) override;

        void OnStateActionsComplete() override;

    private:

        CreateNewFunctionAction m_createNewFunctionAction;
    };

    /**
        EditorAutomationState that will force close the currently opened graph, bypassing any save prompts.
    */
    DefineStateId(ForceCloseActiveGraphState);

    class ForceCloseActiveGraphState 
        : public StaticIdAutomationState<ForceCloseActiveGraphStateId>
    {
    public:

        ForceCloseActiveGraphState();
        ~ForceCloseActiveGraphState() override = default;

    protected:

        void OnSetupStateActions(EditorAutomationActionRunner& actionRunner) override;

    private:

        ForceCloseActiveGraphAction m_forceCloseActiveGraph;
    };
}
